// Persistence of Vision Ray Tracer Scene Description Include File
// File: pgn.inc
// Vers: 3.5
// Desc: part of the pgn2pov package
// Date: 8/22/02
// Auth: cadman

#ifndef (chess_fancy)
	#local chess_fancy=0;
#end

#if (chess_fancy)
	#include "colors.inc"
	#include "textures.inc"
	#include "woods.inc"
	#include "stones1.inc"
#end
#include "chess2.inc"

#declare WHITE=0;
#declare BLACK=1;
#local view_y=64;

#ifndef(_textures)
	#declare _textures=array[4];
#end
#ifndef(_textures[0])
	#declare _textures[0]=texture {
		#if (chess_fancy)
			T_Stone8
		#else
			pigment {
				rgb 1
			}
			finish {
				phong 0.8
				phong_size 100
			}
		#end
	}
#end
#ifndef(_textures[1])
	#declare _textures[1]=texture {
		#if (chess_fancy)
			T_Stone20
		#else
			pigment {
				red .75
			}
			finish {
				phong 0.8
				phong_size 100
			}
		#end
	}
#end
#ifndef(_textures[2])//white's captured pieces
	#declare _textures[2]=texture {
		#if (chess_fancy)
			T_Grnt0a
		#else
			pigment {
				rgbf <1, 1, 1, 0.65>
			}
			finish {
				phong 0.8
				phong_size 100
			}
		#end
	}
#end
#ifndef(_textures[3])//blacks's captured pieces
	#declare _textures[3]=texture {
		#if (chess_fancy)
			T_Grnt12a
		#else
			pigment {
				rgbf <1,0.55,0.55,.75>
			}
			finish {
				phong 0.8
				phong_size 100
			}
		#end
	}
#end

#ifndef(BlackSquare)
	#declare BlackSquare=texture {
		#if (chess_fancy)
			T_Wood14
			rotate <35, 13, 20>
		#else
			pigment {
				rgb 0.25
			}
		#end
	}
#end
#ifndef(WhiteSquare)
	#declare WhiteSquare=texture {
		#if (chess_fancy)
			T_Wood7
			rotate -<35, 13, 20>
		#else
			pigment {
				rgb 1
			}
		#end
	}
#end
#ifndef(T_Board)
	#declare T_Board=texture {
		checker texture {BlackSquare}, texture {WhiteSquare}
		scale 8
	}
#end

#ifndef(T_Table)
	#declare T_Table=texture {
		#if (chess_fancy)
			T_Stone2
			scale 8
		#else
			pigment {
				rgb <0.8, 1, 1>
			}
		#end
	}
#end

#declare cameras=array[2];
#declare cameras[0]=camera {
	location <32, view_y, -60>*<1, .8, .8>
	look_at <32, 0, 32>
	translate x*-4
}
#declare cameras[1]=camera {
	location <32, view_y, 60+64>*<1, .8, .8>
	look_at <32, 0, 32>
	translate x*-4
}

#macro position_piece(position, side)
	#local file=asc(strlwr(substr(position,1,1)))-asc("a")+1;
	//#debug concat("\nfile is ", str(file,0,0))
	#local rank=val(substr(position,2,1));
	//#debug concat("\nrank is ", str(rank,0,0), "\n")
	//texture { _textures[side] }
	#if ((file<1) | (file>8))
		translate y*-1
		texture { _textures[side+2] }
	#else
		texture { _textures[side] }
	#end
	rotate y*side*180
	translate <file-1, 0, rank-1>*8
#end

#macro _Pawn(position, side)
	object {
		Pawn
		position_piece(position, side)
	}
#end
#macro _Knight(position, side)
	object {
		Knight
		position_piece(position, side)
	}
#end
#macro _Rook(position, side)
	object {
		Rook
		position_piece(position, side)
	}
#end
#macro _Bishop(position, side)
	object {
		Bishop
		position_piece(position, side)
	}
#end
#macro _Queen(position, side)
	object {
		Queen
		position_piece(position, side)
	}
#end
#macro _King(position, side)
	object {
		King
		position_piece(position, side)
	}
#end
#macro _Board(side)
	object {
		Board
		texture { T_Board }
	   	translate <-4, 0, -4>
	}
	camera {
		cameras[side]
	}
#end

#macro _Table()
	plane {
		y, -1
		texture { T_Table }
	}
#end

//Persistent objects

light_source {
	<40, 80, -20>
	color rgb <1, 1, 1>
	spotlight
	point_at <32, 0, 32>
	radius 20
}
light_source {
	<10, 70, 20>
	color rgb <0.9, 0.9, 0.8>
	spotlight
	point_at <31, 0, 31>
	radius 25
}
light_source {
	<-20, 100, -20>
	color rgb <0.7, 0.5, 1>*0.6
	spotlight
	point_at <33, 0, 33>
	radius 22
}

